@@ -102,7 +102,7 @@ use utf8;
 use FindBin;
 use POSIX 'strftime';
 
-our $VERSION = '0.0.5'; # VERSION
+our $VERSION = '0.0.6'; # VERSION
 
 use Moose;
 use MooseX::AttributeShortcuts;
@@ -456,6 +456,8 @@ sub _build_tasklist {
     $Rex::Logger::silent = 0;
   }
 
+  ### force use ssh instead openssh
+  set connection => "SSH";
   ### set parallelism
   parallelism($self->parallelism);
   ### set use cache
